import { select, scaleOrdinal, schemePastel1 } from 'd3';
import { observeResize } from '@curran/responsive-axes';
import { one } from './one';
import data from './sharksperdeal.csv';
import { stackedBarChart } from './stackedBarChart';
import { colorLegend } from './colorLegend';

// Parse the data

for (const d of data) {
  d.deals = +d.deals;
  d.country = d.country;
}

const colorValue = (d) => d.shark;
const hoveredStrokeWidth = 1;
const hoveredStrokeColor = 'black';

export const main = (container, { state, setState }) => {
  const dimensions = observeResize({
    state,
    setState,
    container,
  });

  if (dimensions === null) return;

  const { width, height } = dimensions;
  const { hoveredColorValue } = state;

  const setHoveredColorValue = (hoveredColorValue) => {
    setState((state) => ({ ...state, hoveredColorValue }));
  };

  const svg = select(container)
    .selectAll('svg')
    .data([null])
    .join('svg')
    .attr('width', width)
    .attr('height', height);

  const colorScale = scaleOrdinal()
    .domain(data.map(colorValue))
    .range(schemePastel1);

  const stackedBarChartG = one(
    svg,
    'g',
    'stacked-bar-chart',
  );
  const colorLegendG = one(svg, 'g', 'color-legend').attr(
    'transform',
    `translate(${width - 170}, 40)`,
  );

  svg
    .join('text')
    .append('text')
    .text('Industries Sharks Have Invested In')
    .attr('y', 30)
    .attr('x', 350)
    .style('font-size', '1.5em');

  stackedBarChartG.call(stackedBarChart, {
    width,
    height,
    data,
    xValue: (d) => d.deals,
    xAxisLabelText: 'Deals Closed',
    xAxisLabelOffset: 37,
    yValue: (d) => d.industry,
    yAxisLabelText: 'Industry',
    yAxisLabelOffset: 21,
    colorValue,
    colorScale,
    hoveredColorValue,
    hoveredStrokeWidth,
    hoveredStrokeColor,
    marginTop: 40,
    marginBottom: 47,
    marginLeft: 150,
    marginRight: 10,
  });

  colorLegendG.call(colorLegend, {
    colorScale,
    hoveredColorValue,
    setHoveredColorValue,
    hoveredStrokeWidth,
    hoveredStrokeColor,
  });
};
